the_characters: Summarize the Characters

Description Usage Arguments Value Examples

Description

This function provides a brief overview of the character columns in the supplied dataframe. With this function, you can easily discover the number of missing values and the number of unique values.

Usage

1

Arguments

df

dataframe or tibble

Value

tibble, tibble of summary

Examples

1
# the_characters(iris)

nikdata/tellme documentation built on May 30, 2019, 12:02 a.m.