the_numbers: Summarize the numeric values

Description Usage Arguments Value Examples

Description

This function is designed to provide a deeper insight into the numerical values. Think of this function as the base summary function on high-power. With this function, you'll be able to get the min, max, median, and different quartiles in one go.

Usage

1

Arguments

df

dataframe or tibble

Value

tibble, tibble of summary

Examples

1

nikdata/tellme documentation built on May 30, 2019, 12:02 a.m.